# Placeholder Text November 2022

# Excalibrate (Extended xcalibrate) v. 0.0.6
A Bayesian algorithm for calibration of radiometer devices used in 21-cm astrophysics experiments.

Ian Roque, Will Handley & Nima Razavi-Ghods  
Contact: <ilvr2@cam.ac.uk>

Base methodology:  
&nbsp;&nbsp;&nbsp;&nbsp;[arxiv:2011.14052](https://arxiv.org/abs/2011.14052)

Please cite the Excalibrate papers:
* I. L. V. Roque, W. J. Handley, N. Razavi-Ghods, Bayesian noise wave calibration for 21-cm global experiments, *Monthly Notices of the Royal Astronomical Society*, Volume 505, Issue 2, August 2021, Pages 2638–2646.  
<https://academic.oup.com/mnras/article/505/2/2638/6279678>
